%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% escriure_ARR(Graph,constraints_escrites,variables_escrites, %%%%%%%%%%%%%
%              constraints_buscar) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FUNCIONALITAT: %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Escriure totes les relacions entre entrades i sortides que conformen la %
% ARR. %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PARMETRES D'ENTRADA: %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Graph:    Estructura on hi ha totes les subdivisions del graf. %%%%%%%%%%
% constraints_escrites: Vector amb les constraints que ja s'han mostrat %%%
%                       per pantalla. %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% variables_escrites:   Vector amb les variables que ja s'han mostrat per %
%                       pantalla. %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% variables_buscar:     Llistar de constriants que s'han de mostrar les %%%
%                       variables d'entrada i sortida. %%%%%%%%%%%%%%%%%%%%
% pos_zero:             Posici que ocupa la constraint que defineix l' %%%
%                       ARR que busquem. %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function escriure_ARR(Graph,constraints_escrites,variables_escrites,variables_buscar,pos_zero)
% Inicialitzacions:
c_afegides = [];
if isempty(constraints_escrites)
    l = 0;
else
    l = length(constraints_escrites);
end
if l ~= length(Graph.Subgraph)
    %%%%% CONSTRAINTS %%%%%
    nc = length(variables_buscar);
    % Busquem les constraints que reben les variables de sortida a buscar
    for i = 1:nc-1
        % Trobem la posici on es troba la constraint
        pc = pos_constraint(Graph,variables_buscar(i));
        if pc == -1
            % Variable d'entrada
            fprintf(1,'%s->variable coneguda;',char(variables_buscar(i)));
        else
            % Escribim per pantalla la relaci entre sortides i constraints
            fprintf(1,'%s->%s;',char(variables_buscar(i)),char(Graph.Subgraph{pc}.Constraint));
            % Actualitzem les constraints que hem escrit
            constraints_escrites = union(constraints_escrites,Graph.Subgraph{pc}.Sortida);
            % Actualitzem les constraints afegides
            c_afegides = union(c_afegides,pc);
        end
    end
    % s un ZERO
    if pos_zero ~= -1
        % Assignem la posici de la constraint
        pc = pos_zero;
    else
        % Trobem la posici on es troba la constraint
        pc = pos_constraint(Graph,variables_buscar(nc));
    end
    if pc == -1
        % Escribim per pantalla la relaci entre sortides i constraints
        fprintf(1,'%s->variable coneguda\n',char(variables_buscar(nc)));
    else
        % Escribim per pantalla la relaci entre sortides i constraints
        fprintf(1,'%s->%s\n',char(variables_buscar(nc)),char(Graph.Subgraph{pc}.Constraint));
        % Actualitzem les constraints que hem escrit
        constraints_escrites = union(constraints_escrites,Graph.Subgraph{pc}.Sortida);
        % Actualitzem les constraints afegides
        c_afegides = union(c_afegides,pc);
    end
    %%%%% VARIABLES %%%%%
    nc = length(c_afegides);
    if nc > 0
        v_afegides = [];
        string = [];
        % Per cada constraint afegida
        for i = 1:nc-1
            string = sprintf('%s%s%s',string,char(Graph.Subgraph{c_afegides(i)}.Constraint),'->');
            % Per cada variable d'entrada
            nv = length(Graph.Subgraph{c_afegides(i)}.Entrades);
            for j = 1:nv-1
                % Afegim la variable a la lnia
                string = sprintf('%s%s,',string,char(Graph.Subgraph{c_afegides(i)}.Entrades{j}));
                % Actualitzem les variables escrites
                v_afegides = union(v_afegides,cellstr(Graph.Subgraph{c_afegides(i)}.Entrades{j}));
            end
            % Afegim la ltima variable
            string = sprintf('%s%s;',string,char(Graph.Subgraph{c_afegides(i)}.Entrades{nv}));
            % Actualitzem les variables escrites
            v_afegides = union(v_afegides,cellstr(Graph.Subgraph{c_afegides(i)}.Entrades{nv}));
        end
        % Afegim la ltima constraint
        string = sprintf('%s%s%s',string,char(Graph.Subgraph{c_afegides(nc)}.Constraint),'->');
        % Per cada variable d'entrada
        nv = length(Graph.Subgraph{c_afegides(nc)}.Entrades);
        for j = 1:nv-1
            % Afegim la variable a la lnia
            string = sprintf('%s%s,',string,char(Graph.Subgraph{c_afegides(nc)}.Entrades{j}));
            % Actualitzem les variables escrites
            v_afegides = union(v_afegides,cellstr(Graph.Subgraph{c_afegides(nc)}.Entrades{j}));
        end
        % Afegim la ltima variable
        string = sprintf('%s%s;',string,char(Graph.Subgraph{c_afegides(nc)}.Entrades{nv}));
        % Actualitzem les variables escrites
        v_afegides = union(v_afegides,cellstr(Graph.Subgraph{c_afegides(nc)}.Entrades{nv}));
        % Escribim la lnia
        fprintf(1,'%s\n',string);
        if isempty(variables_escrites)
            variables_buscar = v_afegides;
        else
            variables_buscar = setdiff(v_afegides,variables_escrites);
        end
        % Actualitzem les variables escrites
        variables_escrites = union(v_afegides,variables_escrites);
        escriure_ARR(Graph,constraints_escrites,variables_escrites,variables_buscar,-1);
    end
end