%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FUNCIONALITAT: %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% A partir de la matriu amb els rangs i la matriu d'assignacions, retorna %
% l'estructura on es cont la descomposici del graf per a la formaci de %
% l'ARR. %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PARMETRES D'ENTRADA: %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% m_incidencies:    Matriu d'incidncies del sistema. %%%%%%%%%%%%%%%%%%%%%
% m_ranked:         Matriu amb el ranking de les constraints i els zeros. %
% m_assignats:      Matriu amb les constraints que assignen la variable. %%
% variables:        Estructura amb els noms de les variables. %%%%%%%%%%%%%
% constraints:      Estructura amb els noms de les constraints. %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PARMETRES DE SORTIDA: %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% s_graph:  Estructura on es cont la descomposici del graph de les ARR. %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function Graph = formar_graph(m_incidencies, m_ranked,m_assignats,variables,constraints)
% Inicialitzacions
[nc,nv] = size(m_assignats);
c_afegides = 0;
continuar = 1;
rang = 0;
entrades = [];
Graph = [];
c_actual = 1;
% Implementaci
while continuar == 1
    % Trobem totes les constraints del rang
    c_rang = find(m_ranked(:,2) == rang);
    % Per cada constraint del rang
    for i = 1:length(c_rang)
        % Trobem les posicions de les variables desconegudes
        entrades = find(m_incidencies(c_rang(i),:));
        % Eliminem la variable que marquem
        entrades = setdiff(entrades, find(m_assignats(c_rang(i),:)));
        % Afegim les entrades (1's de la matriu d'incidncies no marcats)
        Graph.Subgraph{c_actual}.Entrades = [variables(entrades)];
        % Afegim la constraint
        Graph.Subgraph{c_actual}.Constraint = constraints(c_rang(i));
        if isempty(find(m_assignats(c_rang(i),:)))
            % s un ZERO
            Graph.Subgraph{c_actual}.Sortida = {'ZERO'};
        else
            % Afegim la sortida (1 que marquem)
            Graph.Subgraph{c_actual}.Sortida = variables(find(m_assignats(c_rang(i),:)));
        end
        % Incrementem les constraints afegides
        c_afegides = c_afegides + 1;
        c_actual = c_actual + 1;
    end
    % Incrementem el rang
    rang = rang + 1;
    % Mirem si s'han afegit totes les constraints
    if (c_afegides == nc)
        continuar = 0;
    end
end